package com.aucma.base.mapper;

import java.util.List;
import com.aucma.base.domain.InspectionStandard;

public interface InspectionStandardMapper {
    public InspectionStandard selectInspectionStandardByObjId(Long objId);

    public List<InspectionStandard> selectInspectionStandardList(InspectionStandard inspectionStandard);

    public int insertInspectionStandard(InspectionStandard inspectionStandard);

    public int updateInspectionStandard(InspectionStandard inspectionStandard);

    public int deleteInspectionStandardByObjId(Long objId);

    public int deleteInspectionStandardByObjIds(Long[] objIds);
}
