package com.aucma.base.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.aucma.common.utils.DateUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.aucma.common.annotation.Log;
import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.enums.BusinessType;
import com.aucma.base.domain.InspectionStandard;
import com.aucma.base.service.IInspectionStandardService;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.common.core.page.TableDataInfo;

@RestController
@RequestMapping("/base/inspectionStandard" )
public class InspectionStandardController extends BaseController {
    @Autowired
    private IInspectionStandardService inspectionStandardService;

    @PreAuthorize("@ss.hasPermi('base:inspectionStandard:list')" )
    @GetMapping("/list" )
    public TableDataInfo list(InspectionStandard inspectionStandard) {
        startPage();
        List<InspectionStandard> list = inspectionStandardService.selectInspectionStandardList(inspectionStandard);
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasPermi('base:inspectionStandard:export')" )
    @Log(title = "检验标准" , businessType = BusinessType.EXPORT)
    @PostMapping("/export" )
    public void export(HttpServletResponse response, InspectionStandard inspectionStandard) {
        List<InspectionStandard> list = inspectionStandardService.selectInspectionStandardList(inspectionStandard);
        ExcelUtil<InspectionStandard> util = new ExcelUtil<InspectionStandard>(InspectionStandard. class);
        util.exportExcel(response, list, "检验标准数据" );
    }

    @PreAuthorize("@ss.hasPermi('base:inspectionStandard:query')" )
    @GetMapping(value = "/{objId}" )
    public AjaxResult getInfo(@PathVariable("objId" ) Long objId) {
        return success(inspectionStandardService.selectInspectionStandardByObjId(objId));
    }

    @PreAuthorize("@ss.hasPermi('base:inspectionStandard:add')" )
    @Log(title = "检验标准" , businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody InspectionStandard inspectionStandard) {
        inspectionStandard.setCreatedTime(DateUtils.getNowDate());
        return toAjax(inspectionStandardService.insertInspectionStandard(inspectionStandard));
    }

    @PreAuthorize("@ss.hasPermi('base:inspectionStandard:edit')" )
    @Log(title = "检验标准" , businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody InspectionStandard inspectionStandard) {
        inspectionStandard.setUpdatedTime(DateUtils.getNowDate());
        return toAjax(inspectionStandardService.updateInspectionStandard(inspectionStandard));
    }

    @PreAuthorize("@ss.hasPermi('base:inspectionStandard:remove')" )
    @Log(title = "检验标准" , businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}" )
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(inspectionStandardService.deleteInspectionStandardByObjIds(objIds));
    }

    @PreAuthorize("@ss.hasPermi('base:inspectionStandard:list')" )
    @GetMapping("/getList" )
    public TableDataInfo getList(InspectionStandard inspectionStandard) {
        List<InspectionStandard> list = inspectionStandardService.selectInspectionStandardList(inspectionStandard);
        return getDataTable(list);
    }
}
